==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/CompressedInputStream.h <==
// class gnu.java.net.protocol.ftp.CompressedInputStream

// class file dependencies
// @dep_class 9859c3da5692aeeb gnu_java_net_protocol_ftp_CompressedInputStream
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPInputStream

#include "gnu/java/net/protocol/ftp/DTPInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_CompressedInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_CompressedInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$object;

typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct {
	jint	COMPRESSED;
	jint	EOF;
	jint	FILLER;
	jint	RAW;
};
extern _jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);
extern jint _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *);
extern jint _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$readCodeHeader$40fb6469f8aae0d6(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$readHeader$315d703f8609c43e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$readCodeHeader$40fb6469f8aae0d6;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$readHeader$315d703f8609c43e;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*readCodeHeader$40fb6469f8aae0d6)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);
	void	(*readHeader$315d703f8609c43e)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods	gnu_java_net_protocol_ftp_CompressedInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs	gnu_java_net_protocol_ftp_CompressedInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs {
	jint	descriptor;
	jint	max;
	jint	count;
	jint	state;
	jint	rep;
	jint	n;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_CompressedInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object {
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype _jc_gnu_java_net_protocol_ftp_CompressedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_CompressedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_CompressedInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_CompressedInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/CompressedInputStream.h <==
// class gnu.java.net.protocol.ftp.CompressedInputStream

// class file dependencies
// @dep_class 9859c3da5692aeeb gnu_java_net_protocol_ftp_CompressedInputStream
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPInputStream

#include "gnu/java/net/protocol/ftp/DTPInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_CompressedInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_CompressedInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$object;

typedef struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct {
	jint	COMPRESSED;
	jint	EOF;
	jint	FILLER;
	jint	RAW;
};
extern _jc_gnu_java_net_protocol_ftp_CompressedInputStream$fields_struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$readCodeHeader$40fb6469f8aae0d6(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$readHeader$315d703f8609c43e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$readCodeHeader$40fb6469f8aae0d6;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$readHeader$315d703f8609c43e;
extern _jc_method _jc_gnu_java_net_protocol_ftp_CompressedInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*readCodeHeader$40fb6469f8aae0d6)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;
	void	(*readHeader$315d703f8609c43e)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vmethods	gnu_java_net_protocol_ftp_CompressedInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_refs	gnu_java_net_protocol_ftp_CompressedInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs {
	jint	descriptor;
	jint	max;
	jint	count;
	jint	state;
	jint	rep;
	jint	n;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_gnu_java_net_protocol_ftp_CompressedInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_CompressedInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_CompressedInputStream$object {
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_CompressedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_CompressedInputStream$vtype _jc_gnu_java_net_protocol_ftp_CompressedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_CompressedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_CompressedInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_CompressedInputStream_H_ */
